def count_in_list(l:list,s:str)->int:
 count :int= 0
 for item in l:
    if(item==s):
      count+=1
 return(count)


print(count_in_list(["toto", "tata", "toto"], "toto")) 
# print(count_in_list(["toto", "tata", "toto"], "tutu"))


# from setuptools import setup, find_packages
# setup(
#     name="my_package_raghdaaky",
#     version="1.0",
#     packages=find_packages(where="src"),  # look inside src/
#     package_dir={"": "src"},               # tells setuptools that packages are under src/
#     install_requires=[],                   # dependencies if any
#     python_requires=">=3.10",
# )

from setuptools import setup, find_packages

setup(
    name="my_package_raghdaaky",
    version="1.1",
    packages=find_packages(where="src"),  # look inside src/
    package_dir={"": "src"},               # tells setuptools the root for packages is src/
    install_requires=[],
    python_requires=">=3.10",
)
